@@ -12,7 +12,7 @@ import json
 from dateutil.tz import tzutc
 from dateutil.rrule import rrule, rruleset, WEEKLY, MONTHLY
 
-from vobject import base, iCalendar
+from vobject import VERSION, base, iCalendar
 from vobject import icalendar
 
 from vobject.base import __behaviorRegistry as behavior_registry
@@ -56,7 +56,7 @@ class TestCalendarSerializing(unittest.TestCase):
         """
         CreateCalendar 2.0 format from scratch
         """
-        test_cal = get_test_file("simple_2_0_test.ics")
+        test_cal = get_test_file("simple_2_0_test.ics") % VERSION
         cal = base.newFromBehavior('vcalendar', '2.0')
         cal.add('vevent')
         cal.vevent.add('dtstart').value = datetime.datetime(2006, 5, 9)
@@ -221,7 +221,7 @@ class TestBehaviors(unittest.TestCase):
              'CATEGORIES', 'CLASS', 'COMMENT', 'COMPLETED', 'CONTACT',
              'CREATED', 'DAYLIGHT', 'DESCRIPTION', 'DTEND', 'DTSTAMP',
              'DTSTART', 'DUE', 'DURATION', 'EXDATE', 'EXRULE', 'FN', 'FREEBUSY',
-             'LABEL', 'LAST-MODIFIED', 'LOCATION', 'METHOD', 'N', 'ORG',
+             'GEO', 'LABEL', 'LAST-MODIFIED', 'LOCATION', 'METHOD', 'N', 'ORG',
              'PHOTO', 'PRODID', 'RDATE', 'RECURRENCE-ID', 'RELATED-TO',
              'REQUEST-STATUS', 'RESOURCES', 'RRULE', 'STANDARD', 'STATUS',
              'SUMMARY', 'TRANSP', 'TRIGGER', 'UID', 'VALARM', 'VAVAILABILITY',
@@ -444,6 +444,16 @@ class TestGeneralFileParsing(unittest.TestCase):
              ['NEXT', 'Nope'], ['BAR']]
         )
 
+    def test_quoted_printable(self):
+        """
+        The use of QUOTED-PRINTABLE encoding
+        """
+        ics_str = get_test_file("quoted-printable.ics")
+        vobjs = base.readComponents(ics_str, allowQP=True)
+        for vo in vobjs:
+            self.assertIsNotNone(vo)
+        return
+
 
 class TestVcards(unittest.TestCase):
     """
@@ -984,6 +994,44 @@ class TestCompatibility(unittest.TestCase):
             self.assertIsNotNone(vo)
         return
 
+    def test_radicale_1238_0(self):
+        ics_str = get_test_file("radicale-1238-0.ics")
+        vobjs = base.readComponents(ics_str, allowQP=True)
+        for vo in vobjs:
+            self.assertIsNotNone(vo)
+        return
+
+    def test_radicale_1238_1(self):
+        ics_str = get_test_file("radicale-1238-1.ics")
+        vobjs = base.readComponents(ics_str, allowQP=True)
+        for vo in vobjs:
+            self.assertIsNotNone(vo)
+        return
+
+    def test_radicale_1238_2(self):
+        ics_str = get_test_file("radicale-1238-2.ics")
+        vobjs = base.readComponents(ics_str, allowQP=True)
+        for vo in vobjs:
+            self.assertIsNotNone(vo)
+        return
+
+    def test_radicale_1238_3(self):
+        ics_str = get_test_file("radicale-1238-3.ics")
+        vobjs = base.readComponents(ics_str, allowQP=True)
+        for vo in vobjs:
+            self.assertIsNotNone(vo)
+        return
+
+    def test_radicale_1587(self):
+        vcf_str = get_test_file("radicale-1587.vcf")
+        vobjs = base.readComponents(vcf_str)
+        for vo in vobjs:
+            self.assertIsNotNone(vo)
+            lines = vo.serialize().split("\r\n")
+            for line in lines:
+                if line.startswith("GEO"):
+                    self.assertEqual(line, "GEO:37.386013;-122.082932")
+        return
 
 if __name__ == '__main__':
     unittest.main()
